@@ -2,10 +2,53 @@
 Defines the messages used by SCA2D when checks fail.
 '''
 
+import hashlib
 from dataclasses import dataclass
 import logging
 from colorama import Fore, Back, Style
 
+def gitlab_summary(messages):
+    ''' This returns a list of dictionaries in the form of a gitlab report
+    json.'''
+
+    report = []
+    for message in messages:
+        gl_dict = message_to_gitlab_json(message)
+        if gl_dict is not None:
+            report.append(gl_dict)
+    return report
+
+def message_to_gitlab_json(message):
+    ''' This returns a dictionary for one message representing the json
+    structure needed for a gitlab code quality report'''
+
+    severity = message_severity_gitlab(message)
+    if severity is None:
+        return None
+    fingerprint = hashlib.md5(message.pretty(colour=False).encode('utf-8'))
+    gl_dict = {"description": message.message,
+               "fingerprint": fingerprint.hexdigest(),
+               "severity": severity,
+               "location": {"path": message.filename,
+                            "lines": {"begin": message.line}}}
+    return gl_dict
+
+def message_severity_gitlab(message):
+    '''Convert message code to a gitlab severity level'''
+    code_type = message.code[0]
+    if code_type == "F":
+        return "critical"
+    if code_type == "E":
+        return "major"
+    if code_type == "W":
+        return "minor"
+    if code_type == "I":
+        return "info"
+    if code_type == "D":
+        return "info"
+    #Skip other types
+    return None
+
 
 @dataclass
 class MessageSummary:
@@ -49,7 +92,7 @@ def count_messages(messages):
             summary.debug += 1
     return summary
 
-def print_messages(messages, filename, colour=False, debug=False):
+def print_messages(messages, filename="INPUT_CODE", colour=False, debug=False):
     """
     Print all collected messages for this file.
     """
@@ -59,7 +102,7 @@ def print_messages(messages, filename, colour=False, debug=False):
             if (not debug) and message.code.startswith("U"):
                 #If not in debug mode do not print U-type warnings
                 continue
-            print(message.pretty(filename, colour=colour))
+            print(message.pretty(colour=colour))
     else:
         no_msg_text = (f"{filename} passed all checks!")
         if colour:
@@ -69,9 +112,10 @@ def print_messages(messages, filename, colour=False, debug=False):
 class Message:
     """Class for storing the analysis messages."""
 
-    def __init__(self, code, tree, args=None):
+    def __init__(self, filename, code, tree, args=None):
         if args is None:
             args = []
+        self.filename = filename
         self.code = code
         self.tree = tree
         expected_args = self.raw_message.count('%s')
@@ -100,6 +144,8 @@ class Message:
         '''
         The line in the code where the a check raised this message.
         '''
+        if self.tree.line == 0:
+            return 1
         return self.tree.line
 
     @property
@@ -107,6 +153,8 @@ class Message:
         '''
         The column on Message.line of the code where the a check raised this message.
         '''
+        if self.tree.column == 0:
+            return 1
         return self.tree.column
 
     @property
@@ -132,11 +180,11 @@ class Message:
             return message_txt%self.args
         return message_txt
 
-    def pretty(self, filename="INPUT_CODE", colour=False):
+    def pretty(self, colour=False):
         '''
         Pretty printing the error message. Requires the filename.
         '''
-        msg = f'{filename}:{self.line}:{self.column}: {self.code}: {self.message}'
+        msg = f'{self.filename}:{self.line}:{self.column}: {self.code}: {self.message}'
         if colour:
             if self.code.startswith('F'):
                 msg = Back.RED + msg + Style.RESET_ALL
