@@ -166,7 +166,7 @@ class OuterScope(ScopeContents):
         if self._filename in breadcrumbs:
             crumb_str = ' > '.join(breadcrumbs)
             breadcrumbs.append(self._filename)
-            message = Message("E3003", self._tree, [self._filename, crumb_str])
+            message = Message(self.filename, "E3003", self._tree, [self.filename, crumb_str])
         else:
             breadcrumbs.append(self._filename)
             message = None
@@ -228,10 +228,10 @@ def _loop_over_external_files(file_list, analyser, breadcrumbs, inc_only):
             #Overwrite the dummy mesage tree with the tree of calling statment
             if message.code == "F0001":
                 args = [file_ref.filename, message.args[0], ' > '.join(err_breadcrumbs)]
-                message = Message("E3001", file_ref.tree, args)
+                message = Message(file_scope.filename, "E3001", file_ref.tree, args)
             if message.code == "F0002":
                 args = [file_ref.filename, ' > '.join(err_breadcrumbs)]
-                message = Message("E3002", file_ref.tree, args)
+                message = Message(file_scope.filename, "E3002", file_ref.tree, args)
             all_defs_and_msgs[3].append(message)
             continue
         defs_and_msgs = file_scope.get_external_defintions(analyser,
@@ -240,6 +240,7 @@ def _loop_over_external_files(file_list, analyser, breadcrumbs, inc_only):
         for message in defs_and_msgs[3]:
             #Also overwrite tree with calling statment for any messages raise before.
             message.tree = file_ref.tree
+            message.filename = file_scope.filename
         #Concatenate the variable, module and function definition lists
         all_defs_and_msgs = [i+j for i, j in zip(all_defs_and_msgs, defs_and_msgs)]
     return all_defs_and_msgs
