@@ -54,8 +54,8 @@ class Analyser:
             with open(filename, 'r') as file_obj:
                 scad_code = file_obj.read()
         except (OSError, IOError):
-            return Message("F0002", DummyTree())
-        tree = self._parse_code(scad_code)
+            return Message(filename, "F0002", DummyTree())
+        tree = self._parse_code(scad_code, filename)
         if isinstance(tree, Message):
             #_parse_scope may return a Fatal message instead of a tree
             #return it to be handled later
@@ -63,7 +63,7 @@ class Analyser:
         self._parsed_files[filename] = OuterScope(tree, filename)
         return self._parsed_files[filename]
 
-    def _parse_code(self, scad_code):
+    def _parse_code(self, scad_code, filename="INPUT_CODE"):
         '''
         Parses the scad code and returns the parse tree
         '''
@@ -72,7 +72,7 @@ class Analyser:
         except LarkError as error:
             err_str = "\n"+str(error)
             err_str = err_str.replace('\n', '\n   - ')
-            return Message("F0001", DummyTree(), [err_str])
+            return Message(filename, "F0001", DummyTree(), [err_str])
         return tree
 
     def analyse_file(self, filename, output_tree=False, ignore_list=None):
