@@ -4,7 +4,74 @@ information about certain objects parsed from the .scad file.
 '''
 
 from dataclasses import dataclass
-from lark.tree import Tree
+from lark import Tree, Token
+
+class DummyTree():
+    '''
+    A dummy lark tree. Used for the message class when no tree is available.
+    Returns zero for line or column. It is not subclassed from Tree
+    so it must be expected.
+    '''
+
+    def __init__(self, data=None):
+        if data is None:
+            self.data = 'Dummy'
+        else:
+            self.data = data
+        self.children = []
+
+    @property
+    def line(self):
+        '''
+        Line of the dummy tree is always zero
+        '''
+        return 0
+
+    @property
+    def column(self):
+        '''
+        Column of the dummy tree is always zero
+        '''
+        return 0
+
+class DummyToken():
+    '''
+    A dummy lark token. Used for the message class when no tree is available.
+    Returns zero for line or column. It is not subclassed from Token
+    so it must be expected.
+    '''
+
+    def __init__(self, type_name=None, value=None):
+        if type_name is None:
+            self._type_name = 'Dummy'
+        else:
+            self._type_name = type_name
+        if value is None:
+            self.value = 'Dummy'
+        else:
+            self.value = value
+
+    @property
+    def type(self):
+        """
+        Returns the "type" of token as defined in grammar.
+        """
+        return self._type_name
+
+
+    @property
+    def line(self):
+        '''
+        Line of the dummy tree is always zero
+        '''
+        return 0
+
+    @property
+    def column(self):
+        '''
+        Column of the dummy tree is always zero
+        '''
+        return 0
 
 #TODO: make a base class for all of these and make the __eq__ method safer!
 
@@ -25,6 +92,9 @@ class ModuleDef:
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        return "<sca2d.scadclasses.ModuleDef "+self.name+">"
+
     def __eq__(self, other):
         if isinstance(other, str):
             return self.name == other
@@ -48,6 +118,9 @@ class FunctionDef:
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        return "<sca2d.scadclasses.FunctionDef "+self.name+">"
+
     def __eq__(self, other):
         if isinstance(other, str):
             return self.name == other
@@ -72,6 +145,9 @@ class ModuleCall:
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        return "<sca2d.scadclasses.ModuleCall "+self.name+">"
+
     def __eq__(self, other):
         if isinstance(other, str):
             return self.name == other
@@ -95,6 +171,9 @@ class FunctionCall:
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        return "<sca2d.scadclasses.FunctionCall "+self.name+">"
+
     def __eq__(self, other):
         if isinstance(other, str):
             return self.name == other
@@ -109,14 +188,21 @@ class Variable:
     def __init__(self, token):
         if isinstance(token, Tree):
             token = token.children[0]
-        if token.type != 'VARIABLE':
-            raise ValueError('Cannot make a variable from a non-variable Token')
+        elif isinstance(token, (Token, DummyToken)):
+            if token.type != 'VARIABLE':
+                raise ValueError('Cannot make a variable from a non-variable Token')
+        else:
+            raise TypeError(f'Cannot make a variable from a {type(token)}.'
+                            ' Expecting a Tree or Token.')
         self.name = token.value
         self.token = token
 
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        return "<sca2d.scadclasses.Variable "+self.name+">"
+
     def __eq__(self, other):
         if isinstance(other, str):
             return self.name == other
@@ -126,7 +212,7 @@ class Variable:
     def tree(self):
         """
         returns the token for the variable. This is the same as Variable.token.
-        Despite not being a tree this is safe to use when fidning line and column
+        Despite not being a tree this is safe to use when finding line and column
         numbers.
         """
         return self.token
